@@ -17,12 +17,14 @@
 """
 Event interface.
 """
+import six
 from pyds8k.base import ManagerMeta, ResourceMeta
 from .common.types import DS8K_EVENT
 from .common.base import Base, ReadOnlyManager
 
 
-class Event(Base, metaclass=ResourceMeta):
+@six.add_metaclass(ResourceMeta)
+class Event(Base):
     resource_type = DS8K_EVENT
     # id_field = 'id'
     _template = {'id': '',
@@ -35,7 +37,8 @@ class Event(Base, metaclass=ResourceMeta):
                  }
 
 
-class EventManager(ReadOnlyManager, metaclass=ManagerMeta):
+@six.add_metaclass(ManagerMeta)
+class EventManager(ReadOnlyManager):
     """
     Manage Event resources.
     """
